@@ -1,5 +1,5 @@
 from app.file_parser import *
-from normalize import normalize
+from app.normalize import normalize
 
 
 def goodbye(*args):
